@@ -9,6 +9,8 @@
 package XML::LibXSLT;
 
 use strict;
+use warnings;
+
 use vars qw($VERSION @ISA $USE_LIBXML_DATA_TYPES $MatchCB $ReadCB $OpenCB $CloseCB);
 
 sub REQUIRE_XML_LIBXML_ABI_VERSION { 2 }
@@ -25,7 +27,7 @@ use Carp;
 
 require Exporter;
 
-$VERSION = "1.83";
+$VERSION = '1.85';
 
 require DynaLoader;
 
